import React from 'react'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { FilePicker } from '@pubsweet/ui'
import { compose, withProps } from 'recompose'

import { radiusHelpers } from './styledHelpers'
import {
  Row,
  Item,
  Text,
  Label,
  FileItem,
  ActionLink,
  DragHandle,
  SortableList,
} from './'

const EXTENSIONS = {
  pdf: 'PDF',
  doc: 'Doc',
  docx: 'DocX',
  png: 'PNG',
}

const FileSection = ({
  title,
  isLast,
  isFirst,
  required,
  files = [],
  supportedFormats,
  allowedFileExtensions,
}) => (
  <Root isFirst={isFirst} isLast={isLast}>
    <Row alignItems="center">
      <Item>
        <Label required={required}>{title}</Label>
        <FilePicker
          allowedFileExtensions={allowedFileExtensions}
          onUpload={file => {}}
        >
          <ActionLink icon="plus" size="small">
            UPLOAD FILE
          </ActionLink>
        </FilePicker>
      </Item>
      {supportedFormats && (
        <Item justify="flex-end">
          <Text fontStyle="italic" secondary>
            Supported file formats: {supportedFormats}
          </Text>
        </Item>
      )}
    </Row>
    <SortableList
      dragHandle={DragHandle}
      items={files}
      listItem={FileItem}
      mb={1}
    />
  </Root>
)

export default compose(
  withProps(({ allowedFileExtensions = [] }) => ({
    supportedFormats: allowedFileExtensions
      .map(ext => EXTENSIONS[ext.toLowerCase()])
      .join(', '),
  })),
)(FileSection)

// #region styles
const Root = styled.div`
  background: ${th('colorBackground')};
  min-height: calc(${th('gridUnit')} * 22);
  padding: 0 ${th('gridUnit')};

  ${radiusHelpers};
  border-bottom: ${props => (!props.isLast ? '1px dashed #dbdbdb' : 'none')};
`
// #endregion
