const getEmailCopy = ({
  customId,
  emailType,
  titleText,
  comments = '',
  targetUserName = '',
}) => {
  let paragraph
  let hasLink = true
  switch (emailType) {
    case 'author-request-to-revision':
      paragraph = `In order for ${titleText} to proceed to publication, there needs to be a revision. <br/>
      ${comments}<br/>
        For more information about what is required, please visit the manuscript details page.`
      break
    case 'author-manuscript-rejected':
      paragraph = `I am sorry to inform you that ${titleText} has been rejected for publication. <br/><br/>
    ${comments}<br/><br/>`
      hasLink = false
      break
    case 'author-manuscript-published':
      paragraph = `I am delighted to inform you that ${titleText} has passed through the review process and will be published in Hindawi.<br/><br/>
    Thanks again for choosing to publish with us.`
      hasLink = false
      break
    case 'he-manuscript-rejected':
      hasLink = false
      paragraph = `Thank you for your recommendation to reject ${titleText} based on the reviews you received.<br/><br/>
      I can confirm this article has now been rejected.`
      break
    case 'he-manuscript-published':
      hasLink = false
      paragraph = `Thank you for your recommendation to publish ${titleText} based on the reviews you received.<br/><br/>
      I can confirm this article will now go through to publication.`
      break
    case 'he-manuscript-return-with-comments':
      hasLink = false
      paragraph = `Thank you for your recommendation for ${titleText} based on the reviews you received.<br/><br/>
      ${comments}<br/><br/>`
      break
    case 'accepted-reviewers-after-recommendation':
      hasLink = false
      paragraph = `I appreciate any time you may have spent reviewing ${titleText}. However, an editorial decision has been made and the review of this manuscript is now complete. I apologize for any inconvenience. <br/>
        If you have comments on this manuscript you believe the Editor should see, please email them to Hindawi as soon as possible. <br/>
        Thank you for your interest and I hope you will consider reviewing for Hindawi again.`
      break
    case 'pending-reviewers-after-recommendation':
      hasLink = false
      paragraph = `An editorial decision has been made regarding ${titleText}. So, you do not need to proceed with the review of this manuscript. <br/><br/>
      If you have comments on this manuscript you believe the Editor should see, please email them to Hindawi as soon as possible.`
      break
    case 'submitted-reviewers-after-publish':
      hasLink = false
      paragraph = `Thank you for your review on ${titleText}. After taking into account the reviews and the recommendation of the Handling Editor, I can confirm this article will now be published.<br/><br/>
      If you have any queries about this decision, then please email them to Hindawi as soon as possible.`
      break
    case 'submitted-reviewers-after-reject':
      hasLink = false
      paragraph = `Thank you for your review on ${titleText}. After taking into account the reviews and the recommendation of the Handling Editor, I can confirm this article has now been rejected.<br/><br/>
      If you have any queries about this decision, then please email them to Hindawi as soon as possible.`
      break
    case 'he-review-submitted':
      paragraph = `We are pleased to inform you that Dr. ${targetUserName} has submitted a review for ${titleText}.<br/>
      Please visit the manuscript details page to see the full review.`
      break
    case 'eic-recommend-to-publish-from-he':
      paragraph = `It is my recommendation, based on the reviews I have received for ${titleText} that we should proceed to publication.<br/>
        ${comments}<br/>
        For more information, and to see the full review, please visit the manuscript details page.`
      break
    case 'eic-recommend-to-reject-from-he':
      paragraph = `It is my recommendation, based on the reviews I have received for ${titleText} that we should reject it for publication.<br/>
        ${comments}<br/>
        For more information, and to see the full review, please visit the manuscript details page.`
      break
    case 'eic-request-revision-from-he':
      paragraph = `In order for ${titleText} to proceed to publication, there needs to be a revision. <br/><br/>
        For more information about what is required, please visit the manuscript details page.`
      break
    case 'eqa-manuscript-request-for-approval':
      paragraph = `Manuscript ID ${customId} has passed peer-review and is now ready for EQA. Please click on the link below to either approve or return the manuscript to the Editor in Chief:`
      break
    default:
      throw new Error(`The ${emailType} email type is not defined.`)
  }

  return { paragraph, hasLink }
}

module.exports = {
  getEmailCopy,
}
